<?php

namespace Sprockets\Cache;

/**
 * Cache manager class.
 * This is a Strategy in a Strategy design pattern.
 *
 * @author Gabor Sar <gabor.sar@artoon.hu>
 * @package Sprockets\Cache
 */
class CacheManager
    implements \Sprockets\Cache\CacheManagerInterface
{
    /**
     * Checks whether a file is already cached.
     *
     * @param string $filename
     * @throws Exception
     * @return boolean
     */
    public function exists($filename)
    {
        // check whether the given parameter ($filename) is a string,
        // throw an exception otherwise
        if (!is_string($filename)) {
            throw new Exception('Filename must be a string', 500);
        }

        // return if cache file exists
        return is_file($filename . '.cache');
    }

    /**
     * Returns the cached version of a file.
     *
     * @param string $filename
     * @throws Exception
     * @return string
     */
    public function read($filename)
    {
        // check whether the given parameter ($filename) is a string,
        // throw an exception otherwise
        if (!is_string($filename)) {
            throw new Exception('Filename must be a string', 500);
        }

        // return content of cache file
        return file_get_contents($filename . '.cache');
    }

    /**
     * Caches a file.
     * Returns TRUE if caching was successfull, FALSE otherwise.
     *
     * @param string $filename
     * @param string $content
     * @throws Exception
     * @return boolean
     */
    public function write($filename, $content)
    {
        // check whether the given parameter ($filename) is a string,
        // throw an exception otherwise
        if (!is_string($filename)) {
            throw new Exception('Filename must be a string', 500);
        }

        // check whether the given parameter ($content) is a string,
        // throw an exception otherwise
        if (!is_string($content)) {
            throw new Exception('Content must be a string', 500);
        }

        // cache content
        $success = file_put_contents($filename . '.cache', $content);

        // return true if writing was successful, false otherwise
        return false !== $success;
    }
}
