<?php

namespace Sprockets\Cache;

/**
 * Cache manager interface.
 * This is a StrategyInterface in a Strategy design pattern.
 *
 * @author Gabor Sar <gabor.sar@artoon.hu>
 * @package Sprockets\Cache
 */
interface CacheManagerInterface
{
    /**
     * Checks whether a file is already cached.
     *
     * @param string $filename
     * @throws Exception
     * @return boolean
     */
    public function exists($filename);

    /**
     * Returns the cached version of a file.
     *
     * @param string $filename
     * @throws Exception
     * @return string
     */
    public function read($filename);

    /**
     * Caches a file.
     * Returns TRUE if caching was successfull, FALSE otherwise.
     *
     * @param string $filename
     * @param string $content
     * @throws Exception
     * @return boolean
     */
    public function write($filename, $content);
}
