<?php

namespace Sprockets\Context;

/**
 * Context interface.
 * An instantiation of this will contains the context of
 * the whole application.
 *
 * @author Gabor Sar <gabor.sar@artoon.hu>
 * @package Sprockets\Context
 */
interface ContextInterface
{
    /**
     * Sets basepath.
     *
     * @param string $path
     * @throws Exception
     * @return \Sprockets\Context\ContextInterface
     */
    public function setBasepath($path);

    /**
     * Returns basepath.
     *
     * @retrun string
     */
    public function getBasepath();

    /**
     * Sets (file)extension.
     *
     * @param string $extension
     * @throws Exception
     * @return \Sprockets\Context\ContextInterface
     */
    public function setExtension($extension);

    /**
     * Returns (file)extension.
     *
     * @return string
     */
    public function getExtension();

    /**
     * Sets a path as required.
     *
     * @param string $path
     * @throws Exception
     * @return \Sprockets\Context\ContextInterface
     */
    public function setRequired($path);

    /**
     * Returns whether a path is already required.
     *
     * @param string $path
     * @throws Exception
     * @return boolean;
     */
    public function isRequired($path);

    /**
     * Sets a path as excluded.
     *
     * @param string $path
     * @throws Exception
     * @return \Sprockets\Context\ContextInterface
     */
    public function setExcluded($path);

    /**
     * Returns whether a path is excluded.
     *
     * @param string $path
     * @throws Exception
     * @return boolean
     */
    public function isExcluded($path);

    /**
     * Sets content.
     *
     * @param string $content
     * @throws Exception
     * @return \Sprockets\Context\ContextInterface
     */
    public function setContent($content);

    /**
     * Returns content.
     *
     * @return string
     */
    public function getContent();
}
