<?php

namespace Sprockets\Directive;

/**
 * Directive interface.
 *
 * @author Gabor Sar <gabor.sar@artoon.hu>
 * @package Sprockets\Directive
 */
interface DirectiveInterface
{
    /**
     * Sets comment.
     *
     * @param string $comment
     * @throws Exception
     * @return \Sprockets\Directive\DirectiveInterface
     */
    public function setComment($comment);

    /**
     * Sets name of directive.
     *
     * @param string $name
     * @throws Exception
     * @return \Sprockets\Directive\DirectiveInterface
     */
    public function setName($name);

    /**
     * Sets arguments.
     *
     * @param string $arguments
     * @throws Exception
     * @return \Sprockets\Directive\DirectiveInterface
     */
    public function setArguments($arguments);

    /**
     * Returns the original comment.
     * Can be used to replace it in the current file,
     * to the content of this directive.
     *
     * @return string
     */
    public function getComment();

    /**
     * Returns name.
     * Can be used to decide witch action have to be invoked.
     *
     * @return string
     */
    public function getName();

    /**
     * Returns whether this is a file-type directive.
     *
     * @return boolean
     */
    public function isFile();

    /**
     * Returns the path of this directive.
     *
     * @return string
     */
    public function getPath();

    /**
     * Returns whether the path of this directive is relative to
     * the current file.
     *
     * @return boolean
     */
    public function isRelativeToTheCurrentFile();
}
