<?php

namespace Sprockets\Directive;

/**
 * Directive processor class.
 *
 * @author Gabor Sar <gabor.sar@artoon.hu>
 * @package Sprockets\Directive
 */
class DirectiveProcessor
{
    // regexp patterns
    const DIRECTIVE_PATTERN =
        '%//\=\s+(require|include|stub|require_directory|require_tree)\s+(.*?)\s*[\r\n]%';

    /**
     * Returns all Sprockets type comments of a string.
     *
     * @param string $content Content of the parent file.
     * @throws Exception
     * @return array Array of directives.
     */
    public static function getDirectives($content)
    {
        // check whether the given parameter ($content) is a string,
        // throw an exception otherwise
        if (!is_string($content)) {
            throw new Exception('Content must be a string', 500);
        }

        // get Sprocket friendly comments
        $matches = null;
        preg_match_all(
            self::DIRECTIVE_PATTERN,
            $content,
            $matches,
            PREG_SET_ORDER
        );

        // get directives
        $directives = array();
        foreach ($matches as $attributes) {

            // get named variables
            list($comment, $name, $arguments) = $attributes;

            // instantiate a directive
            $directive = new \Sprockets\Directive\Directive();
            $directive->setComment($comment);
            $directive->setName($name);
            $directive->setArguments($arguments);

            // add this directive to directives (save it)
            $directives[] = $directive;
        }

        // return array of directives
        return $directives;
    }
}
