<?php

namespace Sprockets\Loadpath;

/**
 * Loadpath manager class.
 * This is a Strategy in a Strategy design pattern.
 *
 * @author Gabor Sar <gabor.sar@artoon.hu>
 * @package Sprockets\Loadpath
 */
class LoadpathManager
    implements \Sprockets\Loadpath\LoadpathManagerInterface
{

    /**
     * List of appended paths.
     *
     * @var array
     */
    protected $_loadpaths;

    /**
     * Adds a path to the loadPaths (preferd paths) list.
     *
     * @param string $path
     * @throws Exception
     * @return boolean
     */
    public function appendPath($path)
    {
        // check whether the given parameter ($path) is a string,
        // throw an exception otherwise
        if (!is_string($path)) {
            throw new Exception('Path must be a stirng', 500);
        }

        // append path
        $this->_loadpaths[] = $path;
    }

    /**
     * Returns a path's real location, related to loadPaths,
     * if it is contained by any of them.
     * FALSE returned otherwise.
     *
     * @param string $path
     * @param string $basepath Default value: empty string.
     * @throws Exception
     * @return string|boolean
     */
    public function getPath($path, $basepath = '')
    {
        // check whther the given parameter ($path) is a string,
        // throw an exception otherwise
        if (!is_string($path)) {
            throw new Exception('Path must be a string', 500);
        }

        // check whether the given parameter ($basepath) is a string,
        // throw and exception otherwise
        if (!is_string($basepath)) {
            throw new Exception('Basepath must be a string', 500);
        }

        // check all loadpaths one by one, if any of the contains that path
        foreach ($this->_loadpaths as $loadpath) {

            // get final current path and prefix it with the
            // basepath if required
            $currentPath = ('' === $basepath)
                ? $loadpath . '/' . $path
                : $basepath . '/' . $loadpath . '/' . $path;

            // return current if we found it
            if (file_exists($currentPath)) {
                return $currentPath;
            }
        }

        // return FALSE otherwsise
        return false;
    }
}
