<?php

namespace Sprockets\Processor;

/**
 * Abstract processor.
 * Processors are extensions of Sprockets (like a JS minifer or
 * a Less compiller).
 * This is an Abstract Command in a Command desing pattern.
 *
 * @author Gabor Sar <gabor.sar@artoon.hu>
 * @package Sprockets\Processor
 */
abstract class AbstractProcessor
    implements \Sprockets\CommandInterface
{
    /**
     * Context have to be processed.
     *
     * @var \Sprockets\Context\ContextInterface
     */
    protected $_context = null;

    /**
     * Receiver object.
     * Good idea to instantiate in the concrete processor.
     *
     * @var mixed
     */
    protected $_receiver = null;

    /**
     * Sets context.
     *
     * @param \Sprokets\Context\ContextInterface $context
     * @return \Sprockets\Processor\AbstractProcessor
     */
    public function setContext(\Sprockets\Context\ContextInterface $context)
    {
        // set context
        $this->_context = $context;

        // return self
        return $this;
    }

    /**
     * Executes a command,
     * calls an action of the receiver object.
     */
    abstract public function execute();
}
