###
MainNav controller.
@author Gabor Sar <gabor.sar@artoon.hu>
###

class window.MainNav extends Spine.Controller

    elements:
        '#urlSetsBtn'        : 'urlSetsBtnEl'        # URL sets button
        '#newTestBtn'        : 'newTestBtnEl'        # New test button
        '#testInProgressBtn' : 'testInProgressBtnEl' # Test in progress button

    constructor: ->
        super
        # bind elements' events
        @urlSetsBtnEl.click => Spine.trigger 'navigateto:urlsets'
        @newTestBtnEl.click => Spine.trigger 'navigateto:newtest'
        # bind global events
        Spine.bind 'test:start', => Spine.trigger 'navigateto:testinprogress'
        Spine.bind 'test:stop test:finish', => @finishTest()
        # navigate to a page
        Spine.bind 'navigateto:urlsets', => @urlSets()
        Spine.bind 'navigateto:newtest', => @newTest()
        Spine.bind 'navigateto:testinprogress', => @testInProgress()
        # set new test button as the start / default position
        @newTestBtnEl.button 'toggle'

    # navigate to url sets page
    urlSets: ->
        # disable test in progress button
        # users could not navigate directly to 'test in progress'
        # view, this have to be one across a start test action
        @testInProgressBtnEl.prop 'disabled', true
        # set url sets button as the current tab
        # as the current position
        @urlSetsBtnEl.button 'toggle'

    # navigate to: new test page
    newTest: ->
        # disable test in progress button
        # users could not navigate directly to 'test in progress'
        # view, this have to be one across the start test action
        @testInProgressBtnEl.prop 'disabled', true
        # set new test button as the current tab
        # as the current position
        @newTestBtnEl.button 'toggle'

    # navigate to test in progress page
    testInProgress: ->
        # disable url test button
        @urlSetsBtnEl.prop 'disabled', true
        # disable new test button
        @newTestBtnEl.prop 'disabled', true
        # enable test in progress button
        # we need this, otherwise it is not visible if this
        # is our current tab (position)
        @testInProgressBtnEl.prop 'disabled', false
        # set test in progress button as the current tab
        # as the current position
        @testInProgressBtnEl.button 'toggle'

    finishTest: ->
        # enable url sets button
        @urlSetsBtnEl.prop 'disabled', false
        # enable new test button
        @newTestBtnEl.prop 'disabled', false
