###
NewTest controller.
@author Gabor Sar <gabor.sar@artoon.hu>
###

class window.NewTest extends Spine.Controller

    elements:
        '#label'         : 'labelEl'         # new URL's label
        '#url'           : 'urlEl'           # new URL's URL
        '#saveNewUrlBtn' : 'saveNewUrlBtnEl' # save new URL button
        '#numberOfTests' : 'numberOfTestsEl' # number of test (per URL)
        '#startTestBtn'  : 'startTestBtnEl'  # start test button
        '#urlListTmpl'   : 'urlListTmplEl'   # URL list table template
        '#urlList'       : 'urlListEl'       # URL list table container

    constructor: ->
        super
        # bind elements' events
        @saveNewUrlBtnEl.click => @saveNewUrl()
        @startTestBtnEl.click => @startTest()
        # delegate elements' events
        @el.delegate '#removeAllUrlsBtn', 'click', => @emptyUrls()
        @el.delegate '.btn-remove', 'click', @deleteUrl
        # bind models' events
        Url.bind 'change refresh', => @refreshUrlList()
        # bind global events
        Spine.bind 'navigateto:newtest', => @active()
        Spine.bind 'test:restart', => @startTest()
        # load Url model content from LocalStorage (continue last session)
        Url.loadLocal()

    startTest: ->
        # remove last test result (start a new test, rather then
        # continue the last one)
        Url.destroyAllTestResults()
        # get number of speed tests (per URL)
        numberOfTests = @numberOfTestsEl.val()
        # trigger global event (send message to mediator)
        Spine.trigger 'test:start', numberOfTests

    refreshUrlList: ->
        # save to localStorage
        Url.saveLocal()

        # get parameters to generate template
        params = urls: Url.all()
        # generate template
        tmpl = @urlListTmplEl.tmpl params
        # render view using template
        @urlListEl.html tmpl

        # check if Url model is empty or not
        isEmpty = Url.count() is 0
        # enable start button if Url model is not empty,
        # disable otherwise
        @startTestBtnEl.prop 'disabled', isEmpty

    saveNewUrl: ->
        # create new Url
        url = new Url
            label: @labelEl.val()
            url: @urlEl.val()
        # save it as new record
        url.save()

    deleteUrl: ->
        # get ID of record have to be destroyed
        id = $(@).val()
        # destroy it
        Url.destroy id

    emptyUrls: ->
        # destroy all records of Url model
        Url.destroyAll()
