`//= require ./TestInProgressControl`

###
TestInProgress controller.
@author Gabor Sar <gabor.sar@artoon.hu>
###

class window.TestInProgress extends Spine.Controller

    elements:
        '#progressBar'           : 'progressBarEl'     # progress bar
        '#testResultChart > div' : 'testResultChartEl' # flot chart container
        '#statisticsTmpl'        : 'statisticsTmplEl'  # statistics template
        '#statistics'            : 'statisticsEl'      # statistics container
        '#controlView'           : 'controlViewEl'     # control panel view

    constructor: ->
        super
        # define control panel controller
        @control = new TestInProgressControl el: @controlViewEl
        # define test variables
        @numberOfTests = 0
        @currentTest = 0
        # bind models' events
        Url.bind 'update:testresult', => @updateProgressBar()
        Url.bind 'update:testresult', => @updateFlotChart()
        Url.bind 'update:testresult', => @updateStatistics()
        Url.bind 'update:testresult', => @fetchNextTestResults()
        # bind global events
        Spine.bind 'navigateto:testinprogress', => @active()
        Spine.bind 'test:start', => @showProgressBar()
        Spine.bind 'test:start', => @emptyFlotChart()
        Spine.bind 'test:start', (numberOfTests) => @startTest(numberOfTests)
        Spine.bind 'test:finish', => @hideProgressBar()
        Spine.bind 'test:stop', => @stopTest()
        Spine.bind 'test:stop', => @hideProgressBar()

    startTest: (numberOfTests) ->
        # destroy all previous test results
        Url.destroyAllTestResults()
        # start speed test
        # this is the point where it really starts
        @numberOfTests = numberOfTests
        @currentTest = 0
        Url.fetchTestResults()

    stopTest: ->
        # abort current AJAX request
        Url.request.abort()

    fetchNextTestResults: ->
        # check if have to run more tests
        if ++@currentTest < @numberOfTests
            # start next round
            Url.fetchTestResults()
        else
            # trigger global event (send message to mediator)
            Spine.trigger 'test:finish'

    showProgressBar: ->
        # show progress bar
        @progressBarEl.slideDown 'fast'

    updateProgressBar: ->
        # update progress bar
        progress = (@currentTest + 1) / (@numberOfTests / 100)
        @progressBarEl.find('>.bar').css 'width', progress + '%'

    hideProgressBar: ->
        # hide progress bar
        @progressBarEl.slideUp 'fast', =>
            # set progressbar width to 0%
            # only when it is already hidden
            @progressBarEl.find('>.bar').css 'width', '0%'

    emptyFlotChart: ->
        # update flot chart, using an empty array as data
        @flot = $.plot @testResultChartEl, [], DEFAULT_FLOT_OPTIONS

    updateFlotChart: ->
        # update flot chart
        if @currentTest > 0
            @flot = $.plot(
                @testResultChartEl,
                Url.convertToFlotData(),
                DEFAULT_FLOT_OPTIONS
            )

    updateStatistics: ->
        # get parameters to generate template
        params = urls: Url.all()
        # generate template
        tmpl = @statisticsTmplEl.tmpl params
        # render view using template
        @statisticsEl.html tmpl
