###
UrlSets controller.
@author Gabor Sar <gabor.sar@artoon.hu>
###

class window.UrlSets extends Spine.Controller

    elements:
        '#nameOfNewSet'  : 'nameOfNewSetEl'  # name of new set
        '#saveNewSetBtn' : 'saveNewSetBtnEl' # save new set
        '#urlSetsTmpl'   : 'urlSetsTmplEl'   # URL set list table template
        '#urlSets'       : 'urlSetsEl'       # URL set list table container

    constructor: ->
        super
        # bind elements' events
        @saveNewSetBtnEl.click => @saveNewUrlSet()
        # delegate elements' events
        @el.delegate '#removeAllUrlSetsBtn', 'click', => @emptyUrlSets()
        @el.delegate '.btn-load', 'click', @loadUrlSet
        @el.delegate '.btn-remove', 'click', @deleteUrlSet
        @el.delegate '.btn-overwrite', 'click', @overwriteUrlSet
        # bind models' events
        UrlSet.bind 'change refresh', => @refreshUrlSetList()
        # bind global events
        Spine.bind 'navigateto:urlsets', => @active()
        Spine.bind 'navigateto:urlsets', => @updateInput()
        # load UrlSet model content from LocalStorage (continue last session)
        UrlSet.loadLocal()

    updateInput: ->
        # check if we havea any URLs in the Url model
        # if we have any it means we can seve them in a new set
        # otherwise there is nothing to save
        isEmpty = Url.count() is 0
        # enable new set input fields if we have any URLs to save
        # disable otherwise
        @nameOfNewSetEl.prop 'disabled', isEmpty
        @saveNewSetBtnEl.prop 'disabled', isEmpty

    refreshUrlSetList: ->
        # save to localStorage
        UrlSet.saveLocal()

        # get parameters to generate template
        params = sets: UrlSet.all()
        # generate template
        tmpl = @urlSetsTmplEl.tmpl params
        # render view using template
        @urlSetsEl.html tmpl

    saveNewUrlSet: ->
        # create new UrlSet
        urlSet = new UrlSet
            name: @nameOfNewSetEl.val()
            urls: JSON.stringify(Url)
        # save it as a new record
        urlSet.save()

    overwriteUrlSet: ->
        # get ID of record have to be overwritten
        id = $(@).val()
        # get set (by ID)
        urlSet = UrlSet.find(id)
        # update it
        urlSet.urls = JSON.stringify(Url)
        # save changes
        urlSet.save()

    loadUrlSet: ->
        # get ID of record have to be loaded
        id = $(@).val()
        # get urls (as JSON string)
        urls = UrlSet.find(id).urls
        # refresh Url model
        Url.refresh urls, { clear: true}
        # navigate to new test page
        Spine.trigger 'navigateto:newtest'

    deleteUrlSet: ->
        # get ID of record have to be destroyed
        id = $(@).val()
        # destroy it
        UrlSet.destroy id

    emptyUrlSets: ->
        # destroy all records of UrlSet model
        UrlSet.destroyAll()
