###
Url model.
@author Gabor Sar <gabor.sar@artoon.hu>
###

class window.Url extends Spine.Model

    @extend Spine.Model.Local

    @configure 'Url', 'label', 'url', 'test_results'

    # Returns list of URLs in AJAX friendly,
    # JSON format.
    # @return {Array}
    @urlsToJson: ->
        urls: @all().map (value) ->
            return value.toJSON()

    # Loads (speed) test results per record via AJAX.
    @fetchTestResults: ->
        # @request can be used to abort AJAX request
        @request = jQuery.ajax(
            url: 'ajax/getUrlsSpeed.php',
            type: 'POST',
            dataType: 'json',
            data: @urlsToJson(),
            success: (data) => @addTestResults(data)
        )

    # Adds test results to each records.
    # @param {Object} testResults
    @addTestResults: (testResults) ->
        jQuery.each testResults, (index, value) =>
            @find(index).addTestResult value
        # trigger update event
        this.trigger 'update:testresult'

    # Destroys all test results (per Url record),
    # sets them to empty arrays.
    @destroyAllTestResults: ->
        @each (url) ->
            url.test_results = []
            url.update()

    # Converts content into flot data.
    @convertToFlotData: ->
        # map all urls
        return @all().map (url) ->
            # convert test results into flot friendly format
            url.data = url.test_results.map (testResult, index) ->
                return [index, testResult]
            return url

    # Adds one test result to test_result parameter.
    # Triggers record.update event.
    # @param {Numeric} testResult
    addTestResult: (testResult) ->
        # define test_result as array
        @test_results = [] if !@test_results
        # save new result
        @test_results.push testResult
        # save changes
        @update()

    # Returns min test result (best time).
    # @return {Numeric}
    getMinResult: ->
        if @test_results
            Math.min.apply(Math, @test_results)
        else 0

    # Returns max test result (worst time).
    # @return {Numeric}
    getMaxResult: ->
        if @test_results
            Math.max.apply(Math, @test_results)
        else 0

    # Returns avg test result.
    # @return {Numeric}
    getAvgResult: ->
        if @test_results
            sum = 0
            sum += testResult for testResult, i in @test_results
            avg = (sum / @test_results.length).toFixed 2
        else 0
